{% extends "base.html" %}
{% block title %}Error{% endblock %}

{% block body %}
    <div class="well text-center">
        <h2><i class="fa fa-exclamation-triangle"></i> 404 - Page Not Found</h2>
        <p>
            The page you are looking for could not be found.<br/>
            {% if admin_email %}
                If you think this is an error please <a href="mailto:{{ admin_email }}">contact us</a>.<br/>
            {% endif %}
        </p>
    </div>
{% endblock %}