{% extends "base.html" %}
{% block title %}Graphing Home{% endblock %}
{% load static %}

{% block body %}
    <h2>Instruments</h2>
    <p>Choose the number of runs you want to display on the graph and click 'Graph'.</p>
    <div id="list-container">
        <ul>
            {% for instrument in instruments %}
                <li class="instrument-graph-input-row">
                    <form action="/graph/{{ instrument.name }}">{{ instrument.name }}
                        <label>
                            <input type="number" name="last"
                                   min="1" max="2000"
                                   value="50">
                            most recent runs
                        </label>
                        <input value="Graph" type="submit">
                    </form>
                </li>
            {% endfor %}
        </ul>
    </div>
{% endblock %}

{% block stylesheets %}
    <link rel="stylesheet" href="{% static "css/graphs.css" %}">
{% endblock %}
