{% extends "base.html" %}
{% block title %}Error{% endblock %}

{% block body %}
    <div class="well text-center">
        <h2><i class="fa fa-exclamation-triangle"></i> 500 - An unexpected error occurred</h2>
        <p>
            <i class="fa fa-frown-o"></i> Sorry, something went wrong. Please try again shortly.<br/>
            {% if admin_email %}
                If this error continues please <a href="mailto:{{ admin_email }}">contact us</a>.<br/>
            {% endif %}
        </p>
    </div>
{% endblock %}